OC.L10N.register(
    "bookmarks",
    {
    "Rename" : "ئات ئۆزگەرت",
    "Move" : "Move",
    "Delete" : "ئۆچۈر",
    "New" : "يېڭى",
    "New folder" : "يېڭى قىسقۇچ",
    "Rename folder" : "قىسقۇچ ئاتىنى ئۆزگەرت",
    "Delete folder" : "قىسقۇچ ئۆچۈر",
    "Cancel" : "ۋاز كەچ",
    "Shared with you" : "Shared with you",
    "Files" : "ھۆججەتلەر",
    "Import" : "ئەكىر",
    "Export" : "چىقار",
    "Title" : "ماۋزۇ",
    "Link" : "Link",
    "Tags" : "بەلگەلەر",
    "Notes" : "ئىزاھاتلار",
    "Owner" : "Owner",
    "Sharing" : "ھەمبەھىر",
    "Share link" : "Share link",
    "Folder" : "قىسقۇچ",
    "Save" : "ساقلا"
},
"nplurals=2; plural=(n != 1);");
